PIL Package (autodoc of remaining modules)
==========================================

Reference for modules whose documentation has not yet been ported or written
can be found here.

:mod:`BdfFontFile` Module
-------------------------

.. automodule:: PIL.BdfFontFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ContainerIO` Module
-------------------------

.. automodule:: PIL.ContainerIO
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FontFile` Module
----------------------

.. automodule:: PIL.FontFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`GdImageFile` Module
-------------------------

.. automodule:: PIL.GdImageFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`GimpGradientFile` Module
------------------------------

.. automodule:: PIL.GimpGradientFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`GimpPaletteFile` Module
-----------------------------

.. automodule:: PIL.GimpPaletteFile
    :members:
    :undoc-members:
    :show-inheritance:

.. intentionally skipped documenting this because it's not documented anywhere

:mod:`ImageDraw2` Module
------------------------

.. automodule:: PIL.ImageDraw2
    :members:
    :undoc-members:
    :show-inheritance:

.. intentionally skipped documenting this because it's deprecated

:mod:`ImageFileIO` Module
-------------------------

.. automodule:: PIL.ImageFileIO
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`ImageShow` Module
-----------------------

.. automodule:: PIL.ImageShow
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ImageTransform` Module
----------------------------

.. automodule:: PIL.ImageTransform
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`JpegPresets` Module
-------------------------

.. automodule:: PIL.JpegPresets
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`PaletteFile` Module
-------------------------

.. automodule:: PIL.PaletteFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`PcfFontFile` Module
-------------------------

.. automodule:: PIL.PcfFontFile
    :members:
    :undoc-members:
    :show-inheritance:

:class:`PngImagePlugin.iTXt` Class
----------------------------------

.. autoclass:: PIL.PngImagePlugin.iTXt
    :members:
    :undoc-members:
    :show-inheritance:

    .. method:: __new__(cls, text, lang, tkey)

        :param value: value for this key
        :param lang: language code
        :param tkey: UTF-8 version of the key name

:class:`PngImagePlugin.PngInfo` Class
-------------------------------------

.. autoclass:: PIL.PngImagePlugin.PngInfo
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`TarIO` Module
-------------------

.. automodule:: PIL.TarIO
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`TiffTags` Module
----------------------

.. automodule:: PIL.TiffTags
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`WalImageFile` Module
--------------------------

.. automodule:: PIL.WalImageFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`_binary` Module
---------------------

.. automodule:: PIL._binary
    :members:
    :undoc-members:
    :show-inheritance:

